==> wetterdienst-0.99.0.tar.gz: wetterdienst-0.99.0/docs/data/provider/imgw/hydrology/daily.md <==
# daily

## metadata

| property      | value                                                                                             |
|---------------|---------------------------------------------------------------------------------------------------|
| name          | daily                                                                                             |
| original name | dobowe                                                                                            |
| url           | [here](https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_hydrologiczne/dobowe/) |

## datasets

### hydrology

#### metadata

| property      | value                                                                                             |
|---------------|---------------------------------------------------------------------------------------------------|
| name          | hydrology                                                                                         |
| original name | hydrologia                                                                                        |
| description   | historical daily hydrology data                                                                   |
| access        | [here](https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_hydrologiczne/dobowe/) |

#### parameters

| name              | original name    | description       | unit | original unit | constraints |
|-------------------|------------------|-------------------|------|---------------|-------------|
| discharge         | przepływ         | discharge         | m³/s | m³/s          | >=0         |
| temperature_water | temperatura wody | temperature water | K    | °C            | -           |
| stage             | stan wody        | stage             | m    | cm            | -           |

==> wetterdienst-0.106.0.tar.gz: wetterdienst-0.106.0/docs/data/provider/imgw/hydrology/daily.md <==
# daily

## metadata

| property      | value                                                                                             |
|---------------|---------------------------------------------------------------------------------------------------|
| name          | daily                                                                                             |
| original name | dobowe                                                                                            |
| url           | [here](https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_hydrologiczne/dobowe/) |

## datasets

### hydrology

#### metadata

| property      | value                                                                                             |
|---------------|---------------------------------------------------------------------------------------------------|
| name          | hydrology                                                                                         |
| original name | hydrologia                                                                                        |
| description   | historical daily hydrology data                                                                   |
| access        | [here](https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_hydrologiczne/dobowe/) |

#### parameters

| name              | original name    | description       | unit type       | unit          | constraints |
|-------------------|------------------|-------------------|-----------------|---------------|-------------|
| discharge         | przepływ         | discharge         | volume_per_time | m³/s          | >=0         |
| temperature_water | temperatura wody | temperature water | temperature     | °C            | -           |
| stage             | stan wody        | stage             | length_short    | cm            | -           |
